@@ -7,7 +7,7 @@ from typing import Any, Dict, List, Optional
 import duckdb
 import pandas as pd
 from loguru import logger
-
+from datetime import datetime
 from .exceptions import ConnectionError, QueryError, TableExistsError
 from .helpers import generate_field_metadata
 from .models import FetchParams, FieldsParams
@@ -747,14 +747,34 @@ class HdDB:
     @attach_motherduck
     def update_row(self, org: str, db: str, tbl: str, id: str, data: dict):
         try:
-            # Construct the UPDATE query
-            update_query = f'UPDATE "{org}__{db}".{tbl} SET '
-            for key in data.keys():  # Removed value
-                update_query += f"{key} = ?, "
-            update_query = update_query.rstrip(", ") + " WHERE rcd___id = ?"
+            # 1️⃣ Consultar los tipos de las columnas
+            type_query = f"""
+                SELECT label, type
+                FROM "{org}__{db}".hd_views
+                WHERE tbl = '{tbl}'
+            """
+            column_types = {row[0]: row[1] for row in self.execute(type_query)}
 
-            # Execute the UPDATE query
-            self.execute(update_query, list(data.values()) + [id])
+            # 2️⃣ Procesar valores con base en el tipo
+            processed_values = []
+            for key, value in data.items():
+                col_type = column_types.get(key)
+
+                if col_type in ("Dtm", "Date") and isinstance(value, int):
+                    value = datetime.utcfromtimestamp(value)
+                    if col_type == "Date":
+                        value = value.strftime("%Y-%m-%d")
+                    elif col_type == "Dtm":
+                        value = value.strftime("%Y-%m-%d %H:%M:%S")
+
+                processed_values.append(value)
+
+            # 3️⃣ Armar y ejecutar el query
+            update_query = f'UPDATE "{org}__{db}".{tbl} SET '
+            update_query += ", ".join([f"{key} = ?" for key in data.keys()])
+            update_query += " WHERE rcd___id = ?"
+
+            self.execute(update_query, processed_values + [id])
         except duckdb.Error as e:
             logger.error(f"Error updating row in table {tbl}: {e}")
             raise QueryError(f"Error updating row in table {tbl}: {e}")
@@ -769,7 +789,6 @@ class HdDB:
     ) -> list:
         """
         Retrieve fields from the hd_fields table for a given table.
-
         :param org: Organization name
         :param db: Database name
         :param tbl: Table name
@@ -787,9 +806,20 @@ class HdDB:
                 for row in data:
                     column_type, column_id = row.get("type"), row.get("id")
                     if column_type == "Cat":
-                        query = f'SELECT DISTINCT({column_id}) FROM "{org}__{db}".{tbl}'
-                        categories = self.execute(query).fetchall()
-                        row["categories"] = [c[0] for c in categories]
+                        # Escapar el nombre de la columna con comillas dobles
+                        query = (
+                            f'SELECT DISTINCT("{column_id}") FROM "{org}__{db}"."{tbl}"'
+                        )
+                        try:
+                            categories = self.execute(query).fetchall()
+                            row["categories"] = [
+                                c[0] for c in categories if c[0] is not None
+                            ]
+                        except duckdb.Error as cat_error:
+                            logger.warning(
+                                f"Error fetching categories for column '{column_id}': {cat_error}"
+                            )
+                            row["categories"] = []
 
             return {"data": data}
         except duckdb.Error as e:
@@ -801,16 +831,8 @@ class HdDB:
         try:
             query = f'SELECT * FROM "{org}__{db}".hd_tables WHERE id = ?'
             result = self.execute(query, [tbl]).fetchdf()
-            logger.info("--------------------------------")
-            logger.info("Query result:")
-            logger.info(result)
-            logger.info("--------------------------------")
 
             data = result.to_dict(orient="records")
-            logger.info("Data dictionary:")
-            logger.info(data)
-            logger.info("--------------------------------")
-
             if not data:
                 raise QueryError(f"Table '{tbl}' not found in database '{org}__{db}'")
 
@@ -826,17 +848,30 @@ class HdDB:
                 "updated_at": row_data.get("tb_updated_at"),
                 "magnitude": float(row_data.get("tb_magnitude", 0)),
             }
-
-            logger.info("Final metadata:")
-            logger.info(metadata)
-            logger.info("--------------------------------")
-
             return metadata
 
         except duckdb.Error as e:
             logger.error(f"Error fetching metadata from hd_tables: {e}")
             raise QueryError(f"Error fetching metadata from hd_tables: {e}")
 
+    @attach_motherduck
+    def get_hd_fields(self, org: str, db: str, tbl: str):
+        """
+        Retrieve fields from the hd_fields table for a given table.
+
+        :param org: Organization name
+        :param db: Database name
+        :param tbl: Table name
+        :return: List of fields from hd_fields table
+        :raises QueryError: If there's an error fetching fields from MotherDuck
+        """
+        try:
+            query = f'SELECT * FROM "{org}__{db}".hd_fields WHERE tbl = ?'
+            result = self.execute(query, [tbl]).fetchdf()
+            return result.to_dict(orient="records")
+        except duckdb.Error as e:
+            raise QueryError(f"Error fetching hd_fields: {e}")
+
     @attach_motherduck
     def update_records(
         self, org: str, db: str, tbl: str, updates: List[Dict[str, Any]]
